@@ -60,17 +60,6 @@
 class UtemptProcess : public QProcess
 {
 public:
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-    UtemptProcess()
-    {
-        setChildProcessModifier([this]() {
-            // These are the file descriptors the utempter helper wants
-            dup2(cmdFd, 0);
-            dup2(cmdFd, 1);
-            dup2(cmdFd, 3);
-        });
-    }
-#else
     void setupChildProcess() override
     {
         // These are the file descriptors the utempter helper wants
@@ -78,7 +67,6 @@ public:
         dup2(cmdFd, 1);
         dup2(cmdFd, 3);
     }
-#endif
 
     int cmdFd;
 };
